import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:sudoku/config/default_activity_settings.dart';
import 'package:sudoku/models/settings/settings_activity.dart';

part 'settings_activity_state.dart';

class ActivitySettingsCubit extends HydratedCubit<ActivitySettingsState> {
  ActivitySettingsCubit()
      : super(ActivitySettingsState(settings: ActivitySettings.createDefault()));

  void setValues({
    String? level,
    String? size,
  }) {
    emit(
      ActivitySettingsState(
        settings: ActivitySettings(
          level: level ?? state.settings.level,
          size: size ?? state.settings.size,
        ),
      ),
    );
  }

  String getParameterValue(String code) {
    switch (code) {
      case DefaultActivitySettings.parameterCodeLevel:
        return ActivitySettings.getLevelValueFromUnsafe(state.settings.level);
      case DefaultActivitySettings.parameterCodeSize:
        return ActivitySettings.getSizeValueFromUnsafe(state.settings.size);
    }

    return '';
  }

  void setParameterValue(String code, String value) {
    final String level = (code == DefaultActivitySettings.parameterCodeLevel)
        ? value
        : getParameterValue(DefaultActivitySettings.parameterCodeLevel);
    final String size = (code == DefaultActivitySettings.parameterCodeSize)
        ? value
        : getParameterValue(DefaultActivitySettings.parameterCodeSize);

    setValues(
      level: level,
      size: size,
    );
  }

  @override
  ActivitySettingsState? fromJson(Map<String, dynamic> json) {
    final String level = json[DefaultActivitySettings.parameterCodeLevel] as String;
    final String size = json[DefaultActivitySettings.parameterCodeSize] as String;

    return ActivitySettingsState(
      settings: ActivitySettings(
        level: level,
        size: size,
      ),
    );
  }

  @override
  Map<String, dynamic>? toJson(ActivitySettingsState state) {
    return <String, dynamic>{
      DefaultActivitySettings.parameterCodeLevel: state.settings.level,
      DefaultActivitySettings.parameterCodeSize: state.settings.size,
    };
  }
}
